==> manaplus-1.1.8.21.tar.bz2: manaplus/src/net/ea/adminhandler.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_EA_ADMINHANDLER_H
#define NET_EA_ADMINHANDLER_H

#include "net/adminhandler.h"
#include "net/net.h"

#ifdef __GNUC__
#define A_UNUSED  __attribute__ ((unused))
#else
#define A_UNUSED
#endif

namespace Ea
{

class AdminHandler : public Net::AdminHandler
{
    public:
        virtual ~AdminHandler() { }

        virtual void kick(const std::string &name);

        virtual void ban(int playerId);

        virtual void ban(const std::string &name);

        virtual void unban(int playerId);

        virtual void unban(const std::string &name);

        virtual void mute(int playerId, int type, int limit);

        virtual void warp(std::string map, int x, int y);
};

} // namespace Ea

#endif // NET_EA_ADMINHANDLER_H

==> manaplus-1.1.12.11.tar.bz2: manaplus/src/net/ea/adminhandler.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NET_EA_ADMINHANDLER_H
#define NET_EA_ADMINHANDLER_H

#include "net/adminhandler.h"
#include "net/net.h"

namespace Ea
{

class AdminHandler : public Net::AdminHandler
{
    public:
        virtual ~AdminHandler()
        { }

        virtual void kick(const std::string &name);

        virtual void ban(int playerId);

        virtual void ban(const std::string &name);

        virtual void unban(int playerId);

        virtual void unban(const std::string &name);

        virtual void mute(int playerId, int type, int limit);

        virtual void warp(std::string map, int x, int y);
};

} // namespace Ea

#endif // NET_EA_ADMINHANDLER_H
